@@ -1,6 +1,6 @@
 /*
 BStone: Unofficial source port of Blake Stone: Aliens of Gold and Blake Stone: Planet Strike
-Copyright (c) 2013-2024 Boris I. Bendovsky (bibendovsky@hotmail.com) and Contributors
+Copyright (c) 2013-2025 Boris I. Bendovsky (bibendovsky@hotmail.com) and Contributors
 SPDX-License-Identifier: MIT
 */
 
@@ -20,10 +20,10 @@ class GlR3rContext;
 class GlR3rBuffer : public R3rBuffer
 {
 protected:
-	GlR3rBuffer();
+	GlR3rBuffer() {};
 
 public:
-	~GlR3rBuffer() override;
+	~GlR3rBuffer() override {}
 
 	virtual void set(bool is_set) = 0;
 };
