@@ -1,6 +1,6 @@
 /*
 BStone: Unofficial source port of Blake Stone: Aliens of Gold and Blake Stone: Planet Strike
-Copyright (c) 2024 Boris I. Bendovsky (bibendovsky@hotmail.com) and Contributors
+Copyright (c) 2024-2025 Boris I. Bendovsky (bibendovsky@hotmail.com) and Contributors
 SPDX-License-Identifier: MIT
 */
 
@@ -212,7 +212,7 @@ bool ascii_is_digit(char ch) noexcept
 
 std::string ascii_to_upper(const std::string& string)
 {
-	auto result = string;
+	std::string result = string;
 
 	for (auto& ch : result)
 	{
@@ -654,7 +654,7 @@ bool XmlParser::is_eol(std::intptr_t& eol_length) const
 	switch (peek_char())
 	{
 		case '\r':
-			eol_length = 1 + peek_char(1) == '\n';
+			eol_length = std::intptr_t{1} + (peek_char(1) == '\n');
 			return true;
 
 		case '\n':
@@ -716,7 +716,7 @@ std::intptr_t XmlParser::skip_whitespaces()
 				break;
 
 			case '\r':
-				advance_char(1 + peek_char(1) == '\n');
+				advance_char(std::size_t{1} + (peek_char(1) == '\n'));
 				move_cursor_to_next_line();
 				break;
 
@@ -1201,10 +1201,10 @@ enum class RegistryCTypeSuffix
 
 struct RegistryType
 {
-	bool is_header;
-	std::string name;
-	std::string value;
-	std::size_t apientry_offset; // Zero value for none.
+	bool is_header{};
+	std::string name{};
+	std::string value{};
+	std::size_t apientry_offset{}; // Zero value for none.
 
 	bool has_apientry() const noexcept;
 };
@@ -1225,12 +1225,12 @@ using RegistryTypeNames = std::vector<std::string>;
 
 struct RegistryEnum
 {
-	bool is_bitmask;
-	RegistryApi api;
-	std::string name;
-	std::string alias;
-	std::string value;
-	RegistryCTypeSuffix c_type_suffix;
+	bool is_bitmask{};
+	RegistryApi api{RegistryApi::none};
+	std::string name{};
+	std::string alias{};
+	std::string value{};
+	RegistryCTypeSuffix c_type_suffix{RegistryCTypeSuffix::none};
 };
 
 using RegistryApiToEnumMap = std::unordered_map<RegistryApi, RegistryEnum>;
@@ -1266,10 +1266,10 @@ using RegistryFeatureCommands = std::vector<std::string>;
 
 struct RegistryFeature
 {
-	RegistryApi api;
-	std::string name;
-	std::string number;
-	RegistryFeatureCommands commands;
+	RegistryApi api{RegistryApi::none};
+	std::string name{};
+	std::string number{};
+	RegistryFeatureCommands commands{};
 };
 
 using RegistryFeatureMap = std::unordered_map<std::string, RegistryFeature>;
@@ -3316,7 +3316,7 @@ bool cl_option_value_to_bool(const std::string& value_string)
 int main(int argc, char* argv[])
 try
 {
-	std::cout << "BSTONE OpenGL API generator." << std::endl;
+	std::cout << "BSTONE OpenGL API generator v" << CMAKE_PROJECT_VERSION << std::endl;
 
 	constexpr auto default_indent_with_space = false;
 	constexpr auto default_indent_size = 4;
